@@ -7,7 +7,7 @@ use Catmandu::Fix::Has;
 
 with 'Catmandu::Fix::Inlineable';
 
-our $VERSION = '1.14';
+our $VERSION = '1.15';
 
 has marc_path      => (fix_arg => 1);
 has value          => (fix_arg => 1);
@@ -45,16 +45,16 @@ Set the value of a MARC subfield to a new value.
 
 =head1 METHODS
 
-=head2 marc_set( MARC_PATH , VALUE , [OPT1:VAL, OPT2: VAL])
+=head2 marc_set(MARC_PATH , VALUE)
 
-Set a MARC subfield to a particular new value. This valeu can be a literal or
+Set a MARC subfield to a particular new value. This value can be a literal or
 reference an existing field in the record using the dollar JSON_PATH syntax.
 
 =head1 INLINE
 
 This Fix can be used inline in a Perl script:
 
-    use Catmandu::Fix::marc_set as => 'marc_xmarc_setml';
+    use Catmandu::Fix::marc_set as => 'marc_set';
 
     my $data = { record => [...] };
 
