@@ -15,7 +15,7 @@ memoize('compile_marc_path');
 memoize('parse_marc_spec');
 memoize('_get_index_range');
 
-our $VERSION = '1.14';
+our $VERSION = '1.15';
 
 sub marc_map {
     my $self      = $_[0];
@@ -207,6 +207,125 @@ sub marc_add {
     $data;
 }
 
+sub marc_append {
+    my ($self,$data,$marc_path,$value) = @_;
+    my $record = $data->{'record'};
+
+    return $data unless defined $record;
+
+    if ($value =~ /^\$\.(\S+)/) {
+        my $path = $1;
+        $value = Catmandu::Util::data_at($path,$data);
+    }
+
+    if (Catmandu::Util::is_array_ref $value) {
+        $value = $value->[-1];
+    }
+    elsif (Catmandu::Util::is_hash_ref $value) {
+        my $last;
+        for (keys %$value) {
+            $last = $value->{$_};
+        }
+        $value = $last;
+    }
+
+    my $context = $self->compile_marc_path($marc_path);
+
+    confess "invalid marc path" unless $context;
+
+    for my $field (@$record) {
+        my ($tag, $ind1, $ind2, @subfields) = @$field;
+
+        if ($context->{is_regex_field}) {
+            next unless $tag =~ $context->{field_regex};
+        }
+        else {
+            next unless $tag eq $context->{field};
+        }
+
+        if (defined $context->{ind1}) {
+            if (!defined $ind1 || $ind1 ne $context->{ind1}) {
+                next;
+            }
+        }
+        if (defined $context->{ind2}) {
+            if (!defined $ind2 || $ind2 ne $context->{ind2}) {
+                next;
+            }
+        }
+
+        if ($context->{subfield}) {
+            for (my $i = 0; $i < @subfields; $i += 2) {
+                if ($subfields[$i] =~ $context->{subfield}) {
+                    $field->[$i + 4] .= $value;
+                }
+            }
+        }
+        else {
+            $field->[-1] .= $value;
+        }
+    }
+
+    $data;
+}
+
+sub marc_replace_all {
+    my ($self,$data,$marc_path,$regex,$value) = @_;
+    my $record = $data->{'record'};
+
+    return $data unless defined $record;
+
+    if ($value =~ /^\$\.(\S+)/) {
+        my $path = $1;
+        $value = Catmandu::Util::data_at($path,$data);
+    }
+
+    if (Catmandu::Util::is_array_ref $value) {
+        $value = $value->[-1];
+    }
+    elsif (Catmandu::Util::is_hash_ref $value) {
+        my $last;
+        for (keys %$value) {
+            $last = $value->{$_};
+        }
+        $value = $last;
+    }
+
+    my $context = $self->compile_marc_path($marc_path, subfield_wildcard => 1);
+
+    confess "invalid marc path" unless $context;
+
+    for my $field (@$record) {
+        my ($tag, $ind1, $ind2, @subfields) = @$field;
+
+        if ($context->{is_regex_field}) {
+            next unless $tag =~ $context->{field_regex};
+        }
+        else {
+            next unless $tag eq $context->{field};
+        }
+
+        if (defined $context->{ind1}) {
+            if (!defined $ind1 || $ind1 ne $context->{ind1}) {
+                next;
+            }
+        }
+        if (defined $context->{ind2}) {
+            if (!defined $ind2 || $ind2 ne $context->{ind2}) {
+                next;
+            }
+        }
+
+        for (my $i = 0; $i < @subfields; $i += 2) {
+            if ($subfields[$i] =~ $context->{subfield}) {
+                $field->[$i + 4] =~ s{$regex}{$value}g;
+            }
+        }
+    }
+
+    $data;
+}
+
 sub marc_set {
     my ($self,$data,$marc_path,$value,%opts) = @_;
     my $record = $data->{'record'};
@@ -229,7 +348,7 @@ sub marc_set {
         $value = $last;
     }
 
-    my $context = $self->compile_marc_path($marc_path, subfield_default => 1);
+    my $context = $self->compile_marc_path($marc_path, subfield_wildcard => 1);
 
     confess "invalid marc path" unless $context;
 
@@ -256,7 +375,7 @@ sub marc_set {
 
         my $found = 0;
         for (my $i = 0; $i < @subfields; $i += 2) {
-            if ($subfields[$i] eq $context->{subfield}) {
+            if ($subfields[$i] =~ $context->{subfield}) {
                 if (defined $context->{from}) {
                     substr($field->[$i + 4], $context->{from}, $context->{len}) = $value;
                 }
@@ -336,7 +455,6 @@ sub marc_remove {
     return $data;
 }
 
-
 sub marc_spec {
     my $self      = $_[0];
 
@@ -985,6 +1103,10 @@ Catmandu::MARC - Catmandu modules for working with MARC data
 
 =item * L<Catmandu::Fix::marc_add>
 
+=item * L<Catmandu::Fix::marc_append>
+
+=item * L<Catmandu::Fix::marc_replace_all>
+
 =item * L<Catmandu::Fix::marc_remove>
 
 =item * L<Catmandu::Fix::marc_xml>
@@ -1003,6 +1125,8 @@ Catmandu::MARC - Catmandu modules for working with MARC data
 
 =item * L<Catmandu::Fix::Condition::marc_has_many>
 
+=item * L<Catmandu::Fix::Condition::marc_spec_has>
+
 =item * L<Catmandu::Fix::Inline::marc_map>
 
 =item * L<Catmandu::Fix::Inline::marc_add>
